Discover Packages
github.com/supermodeltools/cli
internal
status
package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Apr 2, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package status implements the `supermodel status` command, which prints
the current authentication state, config path, API endpoint, and local
cache inventory.
This is a vertical slice. It must not import any other slice package.
Run prints the current Supermodel status.
type Options struct {
Output string
}
Options configures the status command.
type Report struct {
Version string `json:"version"`
Authed bool `json:"authenticated"`
APIBase string `json:"api_base"`
ConfigPath string `json:"config_path"`
CacheDir string `json:"cache_dir"`
CacheCount int `json:"cached_analyses"`
}
Report holds all status information.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.